@@ -699,13 +699,25 @@ my %tiff_tags = (
   257   => "height",
   258   => "BitsPerSample",
   259   => { __TAG__ => "Compression",
-	     1 => "PackBytes",
-	     2 => "CCITT Group3",
-	     3 => "CCITT T4",
-	     4 => "CCITT T6",
-	     5 => "LZW",
-	     6 => "JPEG",
-	     32773 => "PackBits",
+		1 => "PackBytes",
+		2 => "CCITT Group3",
+		3 => "CCITT T4",
+		4 => "CCITT T6",
+		5 => "LZW",
+		6 => "JPEG",
+		7 => "JPEG DCT",
+		8 => "Deflate (Adobe)",
+		32766 => "NeXT 2-bit RLE",
+		32771 => "#1 w/ word alignment",
+		32773 => "PackBits (Macintosh RLE)",
+		32809 => "ThunderScan RLE",
+		32895 => "IT8 CT w/padding",
+		32896 => "IT8 Linework RLE",
+		32897 => "IT8 Monochrome picture",
+		32898 => "IT8 Binary line art",
+		32908 => "Pixar companded 10bit LZW",
+		32909 => "Pixar companded 11bit ZIP",
+		32946 => "Deflate",
            },
   262   => { __TAG__ => "PhotometricInterpretation",
 	     0 => "WhiteIsZero",
@@ -726,6 +738,7 @@ my %tiff_tags = (
 	     1 => "LowInHigh",
 	     2 => "HighInLow",
 	   },
+  269   => "DocumentName",
   270   => "ImageDescription",
   271   => "Make",
   272   => "Model",
@@ -805,7 +818,15 @@ sub new
 	while ($ifd) {
 	    push(@{$self->{ifd}}, $ifd);
 	    my($num_fields) = $self->unpack("x$ifd n", $_);
-	    $ifd = $self->unpack("N", substr($_, $ifd + 2 + $num_fields*12, 4));
+	    my $next_ifd = $self->unpack("N", substr($_, $ifd + 2 + $num_fields*12, 4));
+	    # guard against (bug #26127)
+	    $next_ifd = 0 if $next_ifd > length($_);
+	    # guard against looping ifd (bug #26130)
+	    if ($next_ifd <= $ifd) {
+		# bad TIFF header - would cause a loop or strange results
+	        last;
+            }
+        $ifd = $next_ifd;
 	}
     }
 
